Installation — inspire_info 0.1.0 documentation

# Installation

## Stable release

To install inspire_info, run this command in your terminal:

    $ pip install inspire_info

This is the preferred method to install inspire_info, as it will always install the most recent stable release.

If you don’t have pip installed, this Python installation guide can guide you through the process.

## From sources

The sources for inspire_info can be downloaded from the Github repo.

You can either clone the public repository:

    $ git clone git://github.com/WolfXeHD/inspire_info

Or download the tarball:

    $ curl -OJL https://github.com/WolfXeHD/inspire_info/tarball/master

Once you have a copy of the source, you can install it with:

    $ python setup.py install